# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....commons.types.encounter_id import EncounterId
from .billing_note_base import BillingNoteBase
from .billing_note_id import BillingNoteId


class BillingNote(BillingNoteBase):
    """
    Examples
    --------
    import datetime
    import uuid

    from candid.resources.billing_notes.v_2 import BillingNote

    BillingNote(
        billing_note_id=uuid.UUID(
            "99882eea-936f-4e71-bc4f-520e4d14e3e2",
        ),
        encounter_id=uuid.UUID(
            "8bcfb6a8-2876-4111-9e3f-602b541fcf62",
        ),
        created_at=datetime.datetime.fromisoformat(
            "2023-01-01 00:00:00+00:00",
        ),
        author_auth_0_id="F0DE3BF9-F9A1-4FA7-BF6B-28C0B46BADD8",
        author_name="John Doe",
        text="Patient was billed for an MRI.",
    )
    """

    billing_note_id: BillingNoteId
    encounter_id: EncounterId
    created_at: dt.datetime = pydantic.Field()
    """
    An [RFC 3339, section 5.6 datetime](https://ijmacd.github.io/rfc3339-iso8601/).
    For example, 2017-07-21T17:32:28Z.
    """

    author_auth_0_id: typing.Optional[str] = pydantic.Field(alias="author_auth0_id", default=None)
    author_name: typing.Optional[str] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MeasurementUnitCode(str, enum.Enum):
    MILLILITERS = "ML"
    UNITS = "UN"
    GRAMS = "GR"
    INTERNATIONAL_UNIT = "F2"
    MILLIGRAM = "ME"

    def visit(
        self,
        milliliters: typing.Callable[[], T_Result],
        units: typing.Callable[[], T_Result],
        grams: typing.Callable[[], T_Result],
        international_unit: typing.Callable[[], T_Result],
        milligram: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is MeasurementUnitCode.MILLILITERS:
            return milliliters()
        if self is MeasurementUnitCode.UNITS:
            return units()
        if self is MeasurementUnitCode.GRAMS:
            return grams()
        if self is MeasurementUnitCode.INTERNATIONAL_UNIT:
            return international_unit()
        if self is MeasurementUnitCode.MILLIGRAM:
            return milligram()



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .......core.api_error import ApiError
from .......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .......core.jsonable_encoder import jsonable_encoder
from .......core.pydantic_utilities import pydantic_v1
from .......core.request_options import RequestOptions
from ....common.errors.not_found_error import NotFoundError
from ....common.errors.version_conflict_error import VersionConflictError
from ....common.types.appointment_id import AppointmentId
from ....common.types.not_found_error_body import NotFoundErrorBody
from ....common.types.version_conflict_error_body import VersionConflictErrorBody
from .types.appointment import Appointment
from .types.mutable_appointment import MutableAppointment

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self, *, request: MutableAppointment, request_options: typing.Optional[RequestOptions] = None
    ) -> Appointment:
        """
        Adds an appointment. VersionConflictError is returned when the placer_appointment_id is already in use.

        Parameters
        ----------
        request : MutableAppointment

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Appointment

        Examples
        --------
        import datetime

        from candid.client import CandidApiClient
        from candid.resources.pre_encounter.appointments.v_1 import (
            AppointmentStatus,
            AppointmentWorkQueue,
            MutableAppointment,
            Service,
            UniversalServiceIdentifier,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.appointments.v_1.create(
            request=MutableAppointment(
                patient_id="string",
                start_timestamp=datetime.datetime.fromisoformat(
                    "2024-01-15 09:30:00+00:00",
                ),
                status=AppointmentStatus.PENDING,
                service_duration=1,
                services=[
                    Service(
                        universal_service_identifier=UniversalServiceIdentifier.MD_VISIT,
                        start_timestamp=datetime.datetime.fromisoformat(
                            "2024-01-15 09:30:00+00:00",
                        ),
                    )
                ],
                placer_appointment_id="string",
                estimated_copay_cents=1,
                estimated_patient_responsibility_cents=1,
                patient_deposit_cents=1,
                checked_in_timestamp=datetime.datetime.fromisoformat(
                    "2024-01-15 09:30:00+00:00",
                ),
                notes="string",
                location_resource_id="string",
                automated_eligibility_check_complete=True,
                work_queue=AppointmentWorkQueue.EMERGENT_ISSUE,
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "appointments/v1",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(Appointment, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "VersionConflictError":
                raise VersionConflictError(
                    pydantic_v1.parse_obj_as(VersionConflictErrorBody, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "NotFoundError":
                raise NotFoundError(
                    pydantic_v1.parse_obj_as(NotFoundErrorBody, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get(self, id: AppointmentId, *, request_options: typing.Optional[RequestOptions] = None) -> Appointment:
        """
        Gets an appointment.

        Parameters
        ----------
        id : AppointmentId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Appointment

        Examples
        --------
        from candid.client import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.appointments.v_1.get(
            id="string",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"appointments/v1/{jsonable_encoder(id)}",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(Appointment, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "NotFoundError":
                raise NotFoundError(
                    pydantic_v1.parse_obj_as(NotFoundErrorBody, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_history(
        self, id: AppointmentId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[Appointment]:
        """
        Gets an appointment along with it's full history. The return list is ordered by version ascending.

        Parameters
        ----------
        id : AppointmentId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Appointment]

        Examples
        --------
        from candid.client import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.appointments.v_1.get_history(
            id="string",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"appointments/v1/{jsonable_encoder(id)}/history",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(typing.List[Appointment], _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "NotFoundError":
                raise NotFoundError(
                    pydantic_v1.parse_obj_as(NotFoundErrorBody, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update(
        self,
        id: AppointmentId,
        version: str,
        *,
        request: MutableAppointment,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Appointment:
        """
        Updates an appointment. The path must contain the most recent version to prevent race conditions. Updating historic versions is not supported.

        Parameters
        ----------
        id : AppointmentId

        version : str

        request : MutableAppointment

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Appointment

        Examples
        --------
        import datetime

        from candid.client import CandidApiClient
        from candid.resources.pre_encounter.appointments.v_1 import (
            AppointmentStatus,
            AppointmentWorkQueue,
            MutableAppointment,
            Service,
            UniversalServiceIdentifier,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.appointments.v_1.update(
            id="string",
            version="string",
            request=MutableAppointment(
                patient_id="string",
                start_timestamp=datetime.datetime.fromisoformat(
                    "2024-01-15 09:30:00+00:00",
                ),
                status=AppointmentStatus.PENDING,
                service_duration=1,
                services=[
                    Service(
                        universal_service_identifier=UniversalServiceIdentifier.MD_VISIT,
                        start_timestamp=datetime.datetime.fromisoformat(
                            "2024-01-15 09:30:00+00:00",
                        ),
                    )
                ],
                placer_appointment_id="string",
                estimated_copay_cents=1,
                estimated_patient_responsibility_cents=1,
                patient_deposit_cents=1,
                checked_in_timestamp=datetime.datetime.fromisoformat(
                    "2024-01-15 09:30:00+00:00",
                ),
                notes="string",
                location_resource_id="string",
                automated_eligibility_check_complete=True,
                work_queue=AppointmentWorkQueue.EMERGENT_ISSUE,
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"appointments/v1/{jsonable_encoder(id)}/{jsonable_encoder(version)}",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="PUT",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(Appointment, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "NotFoundError":
                raise NotFoundError(
                    pydantic_v1.parse_obj_as(NotFoundErrorBody, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "VersionConflictError":
                raise VersionConflictError(
                    pydantic_v1.parse_obj_as(VersionConflictErrorBody, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def deactivate(
        self, id: AppointmentId, version: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Sets an appointment as deactivated. The path must contain the most recent version to prevent race conditions. Deactivating historic versions is not supported. Subsequent updates via PUT to the appointment will "reactivate" the appointment and set the deactivated flag to false.

        Parameters
        ----------
        id : AppointmentId

        version : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from candid.client import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.appointments.v_1.deactivate(
            id="string",
            version="string",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"appointments/v1/{jsonable_encoder(id)}/{jsonable_encoder(version)}",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "NotFoundError":
                raise NotFoundError(
                    pydantic_v1.parse_obj_as(NotFoundErrorBody, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "VersionConflictError":
                raise VersionConflictError(
                    pydantic_v1.parse_obj_as(VersionConflictErrorBody, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self, *, request: MutableAppointment, request_options: typing.Optional[RequestOptions] = None
    ) -> Appointment:
        """
        Adds an appointment. VersionConflictError is returned when the placer_appointment_id is already in use.

        Parameters
        ----------
        request : MutableAppointment

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Appointment

        Examples
        --------
        import asyncio
        import datetime

        from candid.client import AsyncCandidApiClient
        from candid.resources.pre_encounter.appointments.v_1 import (
            AppointmentStatus,
            AppointmentWorkQueue,
            MutableAppointment,
            Service,
            UniversalServiceIdentifier,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.appointments.v_1.create(
                request=MutableAppointment(
                    patient_id="string",
                    start_timestamp=datetime.datetime.fromisoformat(
                        "2024-01-15 09:30:00+00:00",
                    ),
                    status=AppointmentStatus.PENDING,
                    service_duration=1,
                    services=[
                        Service(
                            universal_service_identifier=UniversalServiceIdentifier.MD_VISIT,
                            start_timestamp=datetime.datetime.fromisoformat(
                                "2024-01-15 09:30:00+00:00",
                            ),
                        )
                    ],
                    placer_appointment_id="string",
                    estimated_copay_cents=1,
                    estimated_patient_responsibility_cents=1,
                    patient_deposit_cents=1,
                    checked_in_timestamp=datetime.datetime.fromisoformat(
                        "2024-01-15 09:30:00+00:00",
                    ),
                    notes="string",
                    location_resource_id="string",
                    automated_eligibility_check_complete=True,
                    work_queue=AppointmentWorkQueue.EMERGENT_ISSUE,
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "appointments/v1",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(Appointment, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "VersionConflictError":
                raise VersionConflictError(
                    pydantic_v1.parse_obj_as(VersionConflictErrorBody, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "NotFoundError":
                raise NotFoundError(
                    pydantic_v1.parse_obj_as(NotFoundErrorBody, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get(self, id: AppointmentId, *, request_options: typing.Optional[RequestOptions] = None) -> Appointment:
        """
        Gets an appointment.

        Parameters
        ----------
        id : AppointmentId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Appointment

        Examples
        --------
        import asyncio

        from candid.client import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.appointments.v_1.get(
                id="string",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"appointments/v1/{jsonable_encoder(id)}",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(Appointment, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "NotFoundError":
                raise NotFoundError(
                    pydantic_v1.parse_obj_as(NotFoundErrorBody, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_history(
        self, id: AppointmentId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[Appointment]:
        """
        Gets an appointment along with it's full history. The return list is ordered by version ascending.

        Parameters
        ----------
        id : AppointmentId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Appointment]

        Examples
        --------
        import asyncio

        from candid.client import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.appointments.v_1.get_history(
                id="string",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"appointments/v1/{jsonable_encoder(id)}/history",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(typing.List[Appointment], _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "NotFoundError":
                raise NotFoundError(
                    pydantic_v1.parse_obj_as(NotFoundErrorBody, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update(
        self,
        id: AppointmentId,
        version: str,
        *,
        request: MutableAppointment,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Appointment:
        """
        Updates an appointment. The path must contain the most recent version to prevent race conditions. Updating historic versions is not supported.

        Parameters
        ----------
        id : AppointmentId

        version : str

        request : MutableAppointment

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Appointment

        Examples
        --------
        import asyncio
        import datetime

        from candid.client import AsyncCandidApiClient
        from candid.resources.pre_encounter.appointments.v_1 import (
            AppointmentStatus,
            AppointmentWorkQueue,
            MutableAppointment,
            Service,
            UniversalServiceIdentifier,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.appointments.v_1.update(
                id="string",
                version="string",
                request=MutableAppointment(
                    patient_id="string",
                    start_timestamp=datetime.datetime.fromisoformat(
                        "2024-01-15 09:30:00+00:00",
                    ),
                    status=AppointmentStatus.PENDING,
                    service_duration=1,
                    services=[
                        Service(
                            universal_service_identifier=UniversalServiceIdentifier.MD_VISIT,
                            start_timestamp=datetime.datetime.fromisoformat(
                                "2024-01-15 09:30:00+00:00",
                            ),
                        )
                    ],
                    placer_appointment_id="string",
                    estimated_copay_cents=1,
                    estimated_patient_responsibility_cents=1,
                    patient_deposit_cents=1,
                    checked_in_timestamp=datetime.datetime.fromisoformat(
                        "2024-01-15 09:30:00+00:00",
                    ),
                    notes="string",
                    location_resource_id="string",
                    automated_eligibility_check_complete=True,
                    work_queue=AppointmentWorkQueue.EMERGENT_ISSUE,
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"appointments/v1/{jsonable_encoder(id)}/{jsonable_encoder(version)}",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="PUT",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(Appointment, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "NotFoundError":
                raise NotFoundError(
                    pydantic_v1.parse_obj_as(NotFoundErrorBody, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "VersionConflictError":
                raise VersionConflictError(
                    pydantic_v1.parse_obj_as(VersionConflictErrorBody, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def deactivate(
        self, id: AppointmentId, version: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Sets an appointment as deactivated. The path must contain the most recent version to prevent race conditions. Deactivating historic versions is not supported. Subsequent updates via PUT to the appointment will "reactivate" the appointment and set the deactivated flag to false.

        Parameters
        ----------
        id : AppointmentId

        version : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from candid.client import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.appointments.v_1.deactivate(
                id="string",
                version="string",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"appointments/v1/{jsonable_encoder(id)}/{jsonable_encoder(version)}",
            base_url=self._client_wrapper.get_environment().pre_encounter,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "NotFoundError":
                raise NotFoundError(
                    pydantic_v1.parse_obj_as(NotFoundErrorBody, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "VersionConflictError":
                raise VersionConflictError(
                    pydantic_v1.parse_obj_as(VersionConflictErrorBody, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import pydantic_v1
from .....core.request_options import RequestOptions
from ....commons.errors.entity_not_found_error import EntityNotFoundError
from ....commons.errors.http_request_validation_error import HttpRequestValidationError
from ....commons.errors.unauthorized_error import UnauthorizedError
from ....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from ....commons.types.request_validation_error import RequestValidationError
from ....commons.types.service_line_id import ServiceLineId
from ....commons.types.unauthorized_error_message import UnauthorizedErrorMessage
from .types.service_line import ServiceLine
from .types.service_line_create_standalone import ServiceLineCreateStandalone
from .types.service_line_update import ServiceLineUpdate

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V2Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self, *, request: ServiceLineCreateStandalone, request_options: typing.Optional[RequestOptions] = None
    ) -> ServiceLine:
        """
        Parameters
        ----------
        request : ServiceLineCreateStandalone

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ServiceLine

        Examples
        --------
        import datetime
        import uuid

        from candid import FacilityTypeCode, ProcedureModifier, ServiceLineUnits
        from candid.client import CandidApiClient
        from candid.resources.service_lines.v_2 import (
            DenialReasonContent,
            ServiceLineCreateStandalone,
            ServiceLineDenialReason,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.service_lines.v_2.create(
            request=ServiceLineCreateStandalone(
                modifiers=[ProcedureModifier.TWENTY_TWO],
                charge_amount_cents=1,
                diagnosis_id_zero=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                diagnosis_id_one=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                diagnosis_id_two=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                diagnosis_id_three=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                denial_reason=ServiceLineDenialReason(
                    reason=DenialReasonContent.AUTHORIZATION_REQUIRED,
                ),
                place_of_service_code=FacilityTypeCode.PHARMACY,
                procedure_code="string",
                quantity="string",
                units=ServiceLineUnits.MJ,
                claim_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                description="string",
                date_of_service=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
                end_date_of_service=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/service-lines/v2",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ServiceLine, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    pydantic_v1.parse_obj_as(RequestValidationError, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update(
        self,
        service_line_id: ServiceLineId,
        *,
        request: ServiceLineUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ServiceLine:
        """
        Parameters
        ----------
        service_line_id : ServiceLineId

        request : ServiceLineUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ServiceLine

        Examples
        --------
        import datetime
        import uuid

        from candid import FacilityTypeCode, ProcedureModifier, ServiceLineUnits
        from candid.client import CandidApiClient
        from candid.resources.service_lines.v_2 import (
            DenialReasonContent,
            DrugIdentification,
            MeasurementUnitCode,
            ServiceIdQualifier,
            ServiceLineDenialReason,
            ServiceLineUpdate,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.service_lines.v_2.update(
            service_line_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=ServiceLineUpdate(
                edit_reason="string",
                modifiers=[ProcedureModifier.TWENTY_TWO],
                charge_amount_cents=1,
                diagnosis_id_zero=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                diagnosis_id_one=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                diagnosis_id_two=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                diagnosis_id_three=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                drug_identification=DrugIdentification(
                    service_id_qualifier=ServiceIdQualifier.EAN_UCC_13,
                    national_drug_code="string",
                    national_drug_unit_count="string",
                    measurement_unit_code=MeasurementUnitCode.MILLILITERS,
                    link_sequence_number="string",
                    pharmacy_prescription_number="string",
                    conversion_formula="string",
                ),
                denial_reason=ServiceLineDenialReason(
                    reason=DenialReasonContent.AUTHORIZATION_REQUIRED,
                ),
                place_of_service_code=FacilityTypeCode.PHARMACY,
                units=ServiceLineUnits.MJ,
                procedure_code="string",
                quantity="string",
                description="string",
                date_of_service=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
                end_date_of_service=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/service-lines/v2/{jsonable_encoder(service_line_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ServiceLine, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    pydantic_v1.parse_obj_as(UnauthorizedErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    pydantic_v1.parse_obj_as(RequestValidationError, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete(
        self, service_line_id: ServiceLineId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        service_line_id : ServiceLineId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import uuid

        from candid.client import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.service_lines.v_2.delete(
            service_line_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/service-lines/v2/{jsonable_encoder(service_line_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    pydantic_v1.parse_obj_as(UnauthorizedErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncV2Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self, *, request: ServiceLineCreateStandalone, request_options: typing.Optional[RequestOptions] = None
    ) -> ServiceLine:
        """
        Parameters
        ----------
        request : ServiceLineCreateStandalone

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ServiceLine

        Examples
        --------
        import asyncio
        import datetime
        import uuid

        from candid import FacilityTypeCode, ProcedureModifier, ServiceLineUnits
        from candid.client import AsyncCandidApiClient
        from candid.resources.service_lines.v_2 import (
            DenialReasonContent,
            ServiceLineCreateStandalone,
            ServiceLineDenialReason,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.service_lines.v_2.create(
                request=ServiceLineCreateStandalone(
                    modifiers=[ProcedureModifier.TWENTY_TWO],
                    charge_amount_cents=1,
                    diagnosis_id_zero=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    diagnosis_id_one=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    diagnosis_id_two=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    diagnosis_id_three=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    denial_reason=ServiceLineDenialReason(
                        reason=DenialReasonContent.AUTHORIZATION_REQUIRED,
                    ),
                    place_of_service_code=FacilityTypeCode.PHARMACY,
                    procedure_code="string",
                    quantity="string",
                    units=ServiceLineUnits.MJ,
                    claim_id=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    description="string",
                    date_of_service=datetime.date.fromisoformat(
                        "2023-01-15",
                    ),
                    end_date_of_service=datetime.date.fromisoformat(
                        "2023-01-15",
                    ),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/service-lines/v2",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ServiceLine, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    pydantic_v1.parse_obj_as(RequestValidationError, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update(
        self,
        service_line_id: ServiceLineId,
        *,
        request: ServiceLineUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ServiceLine:
        """
        Parameters
        ----------
        service_line_id : ServiceLineId

        request : ServiceLineUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ServiceLine

        Examples
        --------
        import asyncio
        import datetime
        import uuid

        from candid import FacilityTypeCode, ProcedureModifier, ServiceLineUnits
        from candid.client import AsyncCandidApiClient
        from candid.resources.service_lines.v_2 import (
            DenialReasonContent,
            DrugIdentification,
            MeasurementUnitCode,
            ServiceIdQualifier,
            ServiceLineDenialReason,
            ServiceLineUpdate,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.service_lines.v_2.update(
                service_line_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=ServiceLineUpdate(
                    edit_reason="string",
                    modifiers=[ProcedureModifier.TWENTY_TWO],
                    charge_amount_cents=1,
                    diagnosis_id_zero=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    diagnosis_id_one=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    diagnosis_id_two=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    diagnosis_id_three=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    drug_identification=DrugIdentification(
                        service_id_qualifier=ServiceIdQualifier.EAN_UCC_13,
                        national_drug_code="string",
                        national_drug_unit_count="string",
                        measurement_unit_code=MeasurementUnitCode.MILLILITERS,
                        link_sequence_number="string",
                        pharmacy_prescription_number="string",
                        conversion_formula="string",
                    ),
                    denial_reason=ServiceLineDenialReason(
                        reason=DenialReasonContent.AUTHORIZATION_REQUIRED,
                    ),
                    place_of_service_code=FacilityTypeCode.PHARMACY,
                    units=ServiceLineUnits.MJ,
                    procedure_code="string",
                    quantity="string",
                    description="string",
                    date_of_service=datetime.date.fromisoformat(
                        "2023-01-15",
                    ),
                    end_date_of_service=datetime.date.fromisoformat(
                        "2023-01-15",
                    ),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/service-lines/v2/{jsonable_encoder(service_line_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ServiceLine, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    pydantic_v1.parse_obj_as(UnauthorizedErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    pydantic_v1.parse_obj_as(RequestValidationError, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete(
        self, service_line_id: ServiceLineId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        service_line_id : ServiceLineId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio
        import uuid

        from candid.client import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.service_lines.v_2.delete(
                service_line_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/service-lines/v2/{jsonable_encoder(service_line_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    pydantic_v1.parse_obj_as(UnauthorizedErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import pydantic_v1
from .....core.request_options import RequestOptions
from ....commons.errors.entity_conflict_error import EntityConflictError
from ....commons.errors.entity_not_found_error import EntityNotFoundError
from ....commons.errors.unprocessable_entity_error import UnprocessableEntityError
from ....commons.types.encounter_id import EncounterId
from ....commons.types.entity_conflict_error_message import EntityConflictErrorMessage
from ....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from ....commons.types.service_line_id import ServiceLineId
from ....commons.types.unprocessable_entity_error_message import UnprocessableEntityErrorMessage
from .types.encounter_provider import EncounterProvider
from .types.initial_referring_provider import InitialReferringProvider
from .types.initial_referring_provider_update import InitialReferringProviderUpdate
from .types.ordering_provider import OrderingProvider
from .types.ordering_provider_update import OrderingProviderUpdate
from .types.referring_provider import ReferringProvider
from .types.referring_provider_update import ReferringProviderUpdate
from .types.supervising_provider import SupervisingProvider
from .types.supervising_provider_update import SupervisingProviderUpdate

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V2Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def update_referring_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: ReferringProviderUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : ReferringProviderUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import CandidApiClient
        from candid.resources.encounter_providers.v_2 import ReferringProviderUpdate

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.update_referring_provider(
            encounter_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=ReferringProviderUpdate(
                npi="string",
                taxonomy_code="string",
                address=StreetAddressLongZip(
                    address_1="123 Main St",
                    address_2="Apt 1",
                    city="New York",
                    state=State.NY,
                    zip_code="10001",
                    zip_plus_four_code="1234",
                ),
                first_name="string",
                last_name="string",
                organization_name="string",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_initial_referring_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: InitialReferringProviderUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : InitialReferringProviderUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import uuid

        from candid import QualifierCode, State, StreetAddressLongZip
        from candid.client import CandidApiClient
        from candid.resources.encounter_providers.v_2 import (
            InitialReferringProviderUpdate,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.update_initial_referring_provider(
            encounter_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=InitialReferringProviderUpdate(
                npi="string",
                taxonomy_code="string",
                address=StreetAddressLongZip(
                    address_1="123 Main St",
                    address_2="Apt 1",
                    city="New York",
                    state=State.NY,
                    zip_code="10001",
                    zip_plus_four_code="1234",
                ),
                qualifier=QualifierCode.DQ,
                first_name="string",
                last_name="string",
                organization_name="string",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/initial-referring-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_supervising_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: SupervisingProviderUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : SupervisingProviderUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import CandidApiClient
        from candid.resources.encounter_providers.v_2 import SupervisingProviderUpdate

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.update_supervising_provider(
            encounter_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=SupervisingProviderUpdate(
                npi="string",
                taxonomy_code="string",
                address=StreetAddressLongZip(
                    address_1="123 Main St",
                    address_2="Apt 1",
                    city="New York",
                    state=State.NY,
                    zip_code="10001",
                    zip_plus_four_code="1234",
                ),
                first_name="string",
                last_name="string",
                organization_name="string",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/supervising-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_ordering_provider(
        self,
        service_line_id: ServiceLineId,
        *,
        request: OrderingProviderUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        service_line_id : ServiceLineId

        request : OrderingProviderUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import CandidApiClient
        from candid.resources.encounter_providers.v_2 import OrderingProviderUpdate

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.update_ordering_provider(
            service_line_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=OrderingProviderUpdate(
                npi="string",
                taxonomy_code="string",
                address=StreetAddressLongZip(
                    address_1="123 Main St",
                    address_2="Apt 1",
                    city="New York",
                    state=State.NY,
                    zip_code="10001",
                    zip_plus_four_code="1234",
                ),
                first_name="string",
                last_name="string",
                organization_name="string",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(service_line_id)}/ordering-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def create_referring_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: ReferringProvider,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : ReferringProvider

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import CandidApiClient
        from candid.resources.encounter_providers.v_2 import ReferringProvider

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.create_referring_provider(
            encounter_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=ReferringProvider(
                npi="string",
                taxonomy_code="string",
                address=StreetAddressLongZip(
                    address_1="123 Main St",
                    address_2="Apt 1",
                    city="New York",
                    state=State.NY,
                    zip_code="10001",
                    zip_plus_four_code="1234",
                ),
                first_name="string",
                last_name="string",
                organization_name="string",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/create-referring-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def create_initial_referring_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: InitialReferringProvider,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : InitialReferringProvider

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import uuid

        from candid import QualifierCode, State, StreetAddressLongZip
        from candid.client import CandidApiClient
        from candid.resources.encounter_providers.v_2 import InitialReferringProvider

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.create_initial_referring_provider(
            encounter_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=InitialReferringProvider(
                npi="string",
                taxonomy_code="string",
                address=StreetAddressLongZip(
                    address_1="123 Main St",
                    address_2="Apt 1",
                    city="New York",
                    state=State.NY,
                    zip_code="10001",
                    zip_plus_four_code="1234",
                ),
                qualifier=QualifierCode.DQ,
                first_name="string",
                last_name="string",
                organization_name="string",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/create-initial-referring-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def create_supervising_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: SupervisingProvider,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : SupervisingProvider

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import CandidApiClient
        from candid.resources.encounter_providers.v_2 import SupervisingProvider

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.create_supervising_provider(
            encounter_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=SupervisingProvider(
                npi="string",
                taxonomy_code="string",
                address=StreetAddressLongZip(
                    address_1="123 Main St",
                    address_2="Apt 1",
                    city="New York",
                    state=State.NY,
                    zip_code="10001",
                    zip_plus_four_code="1234",
                ),
                first_name="string",
                last_name="string",
                organization_name="string",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/create-supervising-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def create_ordering_provider(
        self,
        service_line_id: ServiceLineId,
        *,
        request: OrderingProvider,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        service_line_id : ServiceLineId

        request : OrderingProvider

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import CandidApiClient
        from candid.resources.encounter_providers.v_2 import OrderingProvider

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.create_ordering_provider(
            service_line_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=OrderingProvider(
                npi="string",
                taxonomy_code="string",
                address=StreetAddressLongZip(
                    address_1="123 Main St",
                    address_2="Apt 1",
                    city="New York",
                    state=State.NY,
                    zip_code="10001",
                    zip_plus_four_code="1234",
                ),
                first_name="string",
                last_name="string",
                organization_name="string",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(service_line_id)}/create-ordering-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_referring_provider(
        self, encounter_id: EncounterId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import uuid

        from candid.client import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.delete_referring_provider(
            encounter_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/referring-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_initial_referring_provider(
        self, encounter_id: EncounterId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import uuid

        from candid.client import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.delete_initial_referring_provider(
            encounter_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/initial-referring-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_supervising_provider(
        self, encounter_id: EncounterId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import uuid

        from candid.client import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.delete_supervising_provider(
            encounter_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/supervising-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_ordering_provider(
        self, service_line_id: ServiceLineId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        service_line_id : ServiceLineId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import uuid

        from candid.client import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.encounter_providers.v_2.delete_ordering_provider(
            service_line_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(service_line_id)}/ordering-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncV2Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def update_referring_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: ReferringProviderUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : ReferringProviderUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import asyncio
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import AsyncCandidApiClient
        from candid.resources.encounter_providers.v_2 import ReferringProviderUpdate

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.update_referring_provider(
                encounter_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=ReferringProviderUpdate(
                    npi="string",
                    taxonomy_code="string",
                    address=StreetAddressLongZip(
                        address_1="123 Main St",
                        address_2="Apt 1",
                        city="New York",
                        state=State.NY,
                        zip_code="10001",
                        zip_plus_four_code="1234",
                    ),
                    first_name="string",
                    last_name="string",
                    organization_name="string",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_initial_referring_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: InitialReferringProviderUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : InitialReferringProviderUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import asyncio
        import uuid

        from candid import QualifierCode, State, StreetAddressLongZip
        from candid.client import AsyncCandidApiClient
        from candid.resources.encounter_providers.v_2 import (
            InitialReferringProviderUpdate,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.update_initial_referring_provider(
                encounter_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=InitialReferringProviderUpdate(
                    npi="string",
                    taxonomy_code="string",
                    address=StreetAddressLongZip(
                        address_1="123 Main St",
                        address_2="Apt 1",
                        city="New York",
                        state=State.NY,
                        zip_code="10001",
                        zip_plus_four_code="1234",
                    ),
                    qualifier=QualifierCode.DQ,
                    first_name="string",
                    last_name="string",
                    organization_name="string",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/initial-referring-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_supervising_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: SupervisingProviderUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : SupervisingProviderUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import asyncio
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import AsyncCandidApiClient
        from candid.resources.encounter_providers.v_2 import SupervisingProviderUpdate

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.update_supervising_provider(
                encounter_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=SupervisingProviderUpdate(
                    npi="string",
                    taxonomy_code="string",
                    address=StreetAddressLongZip(
                        address_1="123 Main St",
                        address_2="Apt 1",
                        city="New York",
                        state=State.NY,
                        zip_code="10001",
                        zip_plus_four_code="1234",
                    ),
                    first_name="string",
                    last_name="string",
                    organization_name="string",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/supervising-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_ordering_provider(
        self,
        service_line_id: ServiceLineId,
        *,
        request: OrderingProviderUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        service_line_id : ServiceLineId

        request : OrderingProviderUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import asyncio
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import AsyncCandidApiClient
        from candid.resources.encounter_providers.v_2 import OrderingProviderUpdate

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.update_ordering_provider(
                service_line_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=OrderingProviderUpdate(
                    npi="string",
                    taxonomy_code="string",
                    address=StreetAddressLongZip(
                        address_1="123 Main St",
                        address_2="Apt 1",
                        city="New York",
                        state=State.NY,
                        zip_code="10001",
                        zip_plus_four_code="1234",
                    ),
                    first_name="string",
                    last_name="string",
                    organization_name="string",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(service_line_id)}/ordering-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def create_referring_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: ReferringProvider,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : ReferringProvider

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import asyncio
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import AsyncCandidApiClient
        from candid.resources.encounter_providers.v_2 import ReferringProvider

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.create_referring_provider(
                encounter_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=ReferringProvider(
                    npi="string",
                    taxonomy_code="string",
                    address=StreetAddressLongZip(
                        address_1="123 Main St",
                        address_2="Apt 1",
                        city="New York",
                        state=State.NY,
                        zip_code="10001",
                        zip_plus_four_code="1234",
                    ),
                    first_name="string",
                    last_name="string",
                    organization_name="string",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/create-referring-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def create_initial_referring_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: InitialReferringProvider,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : InitialReferringProvider

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import asyncio
        import uuid

        from candid import QualifierCode, State, StreetAddressLongZip
        from candid.client import AsyncCandidApiClient
        from candid.resources.encounter_providers.v_2 import InitialReferringProvider

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.create_initial_referring_provider(
                encounter_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=InitialReferringProvider(
                    npi="string",
                    taxonomy_code="string",
                    address=StreetAddressLongZip(
                        address_1="123 Main St",
                        address_2="Apt 1",
                        city="New York",
                        state=State.NY,
                        zip_code="10001",
                        zip_plus_four_code="1234",
                    ),
                    qualifier=QualifierCode.DQ,
                    first_name="string",
                    last_name="string",
                    organization_name="string",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/create-initial-referring-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def create_supervising_provider(
        self,
        encounter_id: EncounterId,
        *,
        request: SupervisingProvider,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request : SupervisingProvider

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import asyncio
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import AsyncCandidApiClient
        from candid.resources.encounter_providers.v_2 import SupervisingProvider

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.create_supervising_provider(
                encounter_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=SupervisingProvider(
                    npi="string",
                    taxonomy_code="string",
                    address=StreetAddressLongZip(
                        address_1="123 Main St",
                        address_2="Apt 1",
                        city="New York",
                        state=State.NY,
                        zip_code="10001",
                        zip_plus_four_code="1234",
                    ),
                    first_name="string",
                    last_name="string",
                    organization_name="string",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/create-supervising-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def create_ordering_provider(
        self,
        service_line_id: ServiceLineId,
        *,
        request: OrderingProvider,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterProvider:
        """
        Parameters
        ----------
        service_line_id : ServiceLineId

        request : OrderingProvider

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterProvider

        Examples
        --------
        import asyncio
        import uuid

        from candid import State, StreetAddressLongZip
        from candid.client import AsyncCandidApiClient
        from candid.resources.encounter_providers.v_2 import OrderingProvider

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.create_ordering_provider(
                service_line_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=OrderingProvider(
                    npi="string",
                    taxonomy_code="string",
                    address=StreetAddressLongZip(
                        address_1="123 Main St",
                        address_2="Apt 1",
                        city="New York",
                        state=State.NY,
                        zip_code="10001",
                        zip_plus_four_code="1234",
                    ),
                    first_name="string",
                    last_name="string",
                    organization_name="string",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(service_line_id)}/create-ordering-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(EncounterProvider, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_referring_provider(
        self, encounter_id: EncounterId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio
        import uuid

        from candid.client import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.delete_referring_provider(
                encounter_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/referring-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_initial_referring_provider(
        self, encounter_id: EncounterId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio
        import uuid

        from candid.client import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.delete_initial_referring_provider(
                encounter_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/initial-referring-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_supervising_provider(
        self, encounter_id: EncounterId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio
        import uuid

        from candid.client import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.delete_supervising_provider(
                encounter_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(encounter_id)}/supervising-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_ordering_provider(
        self, service_line_id: ServiceLineId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Parameters
        ----------
        service_line_id : ServiceLineId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio
        import uuid

        from candid.client import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.encounter_providers.v_2.delete_ordering_provider(
                service_line_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-providers/v2/{jsonable_encoder(service_line_id)}/ordering-provider",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MaritalStatus(str, enum.Enum):
    ANNULLED = "ANNULLED"
    DIVORCED = "DIVORCED"
    INTERLOCUTORY = "INTERLOCUTORY"
    SEPARATED = "SEPARATED"
    MARRIED = "MARRIED"
    COMMON_LAW = "COMMON_LAW"
    POLYGAMOUS = "POLYGAMOUS"
    DOMESTIC_PARTNER = "DOMESTIC_PARTNER"
    UNMARRIED = "UNMARRIED"
    NEVER_MARRIED = "NEVER_MARRIED"
    WIDOWED = "WIDOWED"
    UNKNOWN = "UNKNOWN"

    def visit(
        self,
        annulled: typing.Callable[[], T_Result],
        divorced: typing.Callable[[], T_Result],
        interlocutory: typing.Callable[[], T_Result],
        separated: typing.Callable[[], T_Result],
        married: typing.Callable[[], T_Result],
        common_law: typing.Callable[[], T_Result],
        polygamous: typing.Callable[[], T_Result],
        domestic_partner: typing.Callable[[], T_Result],
        unmarried: typing.Callable[[], T_Result],
        never_married: typing.Callable[[], T_Result],
        widowed: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is MaritalStatus.ANNULLED:
            return annulled()
        if self is MaritalStatus.DIVORCED:
            return divorced()
        if self is MaritalStatus.INTERLOCUTORY:
            return interlocutory()
        if self is MaritalStatus.SEPARATED:
            return separated()
        if self is MaritalStatus.MARRIED:
            return married()
        if self is MaritalStatus.COMMON_LAW:
            return common_law()
        if self is MaritalStatus.POLYGAMOUS:
            return polygamous()
        if self is MaritalStatus.DOMESTIC_PARTNER:
            return domestic_partner()
        if self is MaritalStatus.UNMARRIED:
            return unmarried()
        if self is MaritalStatus.NEVER_MARRIED:
            return never_married()
        if self is MaritalStatus.WIDOWED:
            return widowed()
        if self is MaritalStatus.UNKNOWN:
            return unknown()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....commons.types.claim_id import ClaimId
from .....commons.types.service_line_id import ServiceLineId
from .....x_12.resources.v_1.types.claim_adjustment_reason_code import ClaimAdjustmentReasonCode
from .service_line_adjudication import ServiceLineAdjudication


class ClaimAdjudication(pydantic.BaseModel):
    claim_id: ClaimId
    insurance_allowed_amount_cents: typing.Optional[int] = None
    insurance_paid_amount_cents: typing.Optional[int] = None
    charge_amount_cents: typing.Optional[int] = None
    service_lines: typing.Dict[ServiceLineId, typing.List[ServiceLineAdjudication]]
    payer_claim_number: typing.Optional[str] = None
    carcs: typing.List[ClaimAdjustmentReasonCode]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.version_conflict_error_body import VersionConflictErrorBody


class VersionConflictError(ApiError):
    def __init__(self, body: VersionConflictErrorBody):
        super().__init__(status_code=409, body=body)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....invoices.resources.v_2.types.invoice_item_create import InvoiceItemCreate
from .invoice_item_update_type import InvoiceItemUpdateType


class InvoiceItemInfoUpdate(pydantic.BaseModel):
    update_type: InvoiceItemUpdateType = pydantic.Field()
    """
    The only supported update operations for invoice items is to either overwrite the entire list of invoice items
    or to append new invoice items
    """

    items: typing.List[InvoiceItemCreate]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .non_insurance_payer_id import NonInsurancePayerId


class NonInsurancePayer(pydantic.BaseModel):
    """
    Examples
    --------
    import uuid

    from candid.resources.non_insurance_payers.v_1 import NonInsurancePayer

    NonInsurancePayer(
        non_insurance_payer_id=uuid.UUID(
            "eb7623ab-d5bc-4b25-b257-2b8fcec578de",
        ),
        name="Sunrise Foundation",
        category="Foundation",
        description="Sunrise Foundation is a non-profit organization that provides financial assistance to patients in need.",
        enabled=True,
    )
    """

    non_insurance_payer_id: NonInsurancePayerId
    name: str
    description: typing.Optional[str] = None
    category: typing.Optional[str] = None
    enabled: bool

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from ....core.api_error import ApiError
from ..types.unauthorized_error_message import UnauthorizedErrorMessage


class UnauthorizedError(ApiError):
    def __init__(self, body: UnauthorizedErrorMessage):
        super().__init__(status_code=403, body=body)



# This file was auto-generated by Fern from our API Definition.

from .appointment import Appointment
from .appointment_status import AppointmentStatus
from .appointment_work_queue import AppointmentWorkQueue
from .mutable_appointment import MutableAppointment
from .service import Service
from .universal_service_identifier import UniversalServiceIdentifier

__all__ = [
    "Appointment",
    "AppointmentStatus",
    "AppointmentWorkQueue",
    "MutableAppointment",
    "Service",
    "UniversalServiceIdentifier",
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    BillingProvider,
    EncounterProvider,
    EncounterProviderBase,
    InitialReferringProvider,
    InitialReferringProviderUpdate,
    OrderingProvider,
    OrderingProviderUpdate,
    ProviderId,
    ReferringProvider,
    ReferringProviderUpdate,
    RenderingProvider,
    SupervisingProvider,
    SupervisingProviderUpdate,
)

__all__ = [
    "BillingProvider",
    "EncounterProvider",
    "EncounterProviderBase",
    "InitialReferringProvider",
    "InitialReferringProviderUpdate",
    "OrderingProvider",
    "OrderingProviderUpdate",
    "ProviderId",
    "ReferringProvider",
    "ReferringProviderUpdate",
    "RenderingProvider",
    "SupervisingProvider",
    "SupervisingProviderUpdate",
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    CreateThirdPartyPayerRequest,
    ThirdPartyPayer,
    ThirdPartyPayerCategoryUpdate,
    ThirdPartyPayerCategoryUpdate_Remove,
    ThirdPartyPayerCategoryUpdate_Set,
    ThirdPartyPayerDescriptionUpdate,
    ThirdPartyPayerDescriptionUpdate_Remove,
    ThirdPartyPayerDescriptionUpdate_Set,
    ThirdPartyPayerId,
    ThirdPartyPayerPage,
    ThirdPartyPayerSortField,
    ThirdPartyPayerUpdateRequest,
    ToggleThirdPartyPayerEnablementRequest,
)

__all__ = [
    "CreateThirdPartyPayerRequest",
    "ThirdPartyPayer",
    "ThirdPartyPayerCategoryUpdate",
    "ThirdPartyPayerCategoryUpdate_Remove",
    "ThirdPartyPayerCategoryUpdate_Set",
    "ThirdPartyPayerDescriptionUpdate",
    "ThirdPartyPayerDescriptionUpdate_Remove",
    "ThirdPartyPayerDescriptionUpdate_Set",
    "ThirdPartyPayerId",
    "ThirdPartyPayerPage",
    "ThirdPartyPayerSortField",
    "ThirdPartyPayerUpdateRequest",
    "ToggleThirdPartyPayerEnablementRequest",
]



# This file was auto-generated by Fern from our API Definition.

from .appointment_list_item import AppointmentListItem
from .appointment_list_page import AppointmentListPage
from .filter_query_string import FilterQueryString
from .patient_list_item import PatientListItem
from .patient_list_page import PatientListPage

__all__ = ["AppointmentListItem", "AppointmentListPage", "FilterQueryString", "PatientListItem", "PatientListPage"]



# This file was auto-generated by Fern from our API Definition.

from ........core.api_error import ApiError
from ..types.potential_duplicate_patients_error_body import PotentialDuplicatePatientsErrorBody


class PotentialDuplicatePatients(ApiError):
    def __init__(self, body: PotentialDuplicatePatientsErrorBody):
        super().__init__(status_code=409, body=body)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class State(str, enum.Enum):
    AA = "AA"
    AE = "AE"
    AP = "AP"
    AL = "AL"
    AK = "AK"
    AS = "AS"
    AZ = "AZ"
    AR = "AR"
    CA = "CA"
    CO = "CO"
    CT = "CT"
    DC = "DC"
    DE = "DE"
    FL = "FL"
    FM = "FM"
    GA = "GA"
    GU = "GU"
    HI = "HI"
    ID = "ID"
    IL = "IL"
    IN = "IN"
    IA = "IA"
    KS = "KS"
    KY = "KY"
    LA = "LA"
    ME = "ME"
    MD = "MD"
    MA = "MA"
    MH = "MH"
    MI = "MI"
    MN = "MN"
    MP = "MP"
    MS = "MS"
    MO = "MO"
    MT = "MT"
    NE = "NE"
    NV = "NV"
    NH = "NH"
    NJ = "NJ"
    NM = "NM"
    NY = "NY"
    NC = "NC"
    ND = "ND"
    OH = "OH"
    OK = "OK"
    OR = "OR"
    PA = "PA"
    PR = "PR"
    PW = "PW"
    RI = "RI"
    SC = "SC"
    SD = "SD"
    TN = "TN"
    TX = "TX"
    UT = "UT"
    VI = "VI"
    VT = "VT"
    VA = "VA"
    WA = "WA"
    WV = "WV"
    WI = "WI"
    WY = "WY"

    def visit(
        self,
        aa: typing.Callable[[], T_Result],
        ae: typing.Callable[[], T_Result],
        ap: typing.Callable[[], T_Result],
        al: typing.Callable[[], T_Result],
        ak: typing.Callable[[], T_Result],
        as_: typing.Callable[[], T_Result],
        az: typing.Callable[[], T_Result],
        ar: typing.Callable[[], T_Result],
        ca: typing.Callable[[], T_Result],
        co: typing.Callable[[], T_Result],
        ct: typing.Callable[[], T_Result],
        dc: typing.Callable[[], T_Result],
        de: typing.Callable[[], T_Result],
        fl: typing.Callable[[], T_Result],
        fm: typing.Callable[[], T_Result],
        ga: typing.Callable[[], T_Result],
        gu: typing.Callable[[], T_Result],
        hi: typing.Callable[[], T_Result],
        id: typing.Callable[[], T_Result],
        il: typing.Callable[[], T_Result],
        in_: typing.Callable[[], T_Result],
        ia: typing.Callable[[], T_Result],
        ks: typing.Callable[[], T_Result],
        ky: typing.Callable[[], T_Result],
        la: typing.Callable[[], T_Result],
        me: typing.Callable[[], T_Result],
        md: typing.Callable[[], T_Result],
        ma: typing.Callable[[], T_Result],
        mh: typing.Callable[[], T_Result],
        mi: typing.Callable[[], T_Result],
        mn: typing.Callable[[], T_Result],
        mp: typing.Callable[[], T_Result],
        ms: typing.Callable[[], T_Result],
        mo: typing.Callable[[], T_Result],
        mt: typing.Callable[[], T_Result],
        ne: typing.Callable[[], T_Result],
        nv: typing.Callable[[], T_Result],
        nh: typing.Callable[[], T_Result],
        nj: typing.Callable[[], T_Result],
        nm: typing.Callable[[], T_Result],
        ny: typing.Callable[[], T_Result],
        nc: typing.Callable[[], T_Result],
        nd: typing.Callable[[], T_Result],
        oh: typing.Callable[[], T_Result],
        ok: typing.Callable[[], T_Result],
        or_: typing.Callable[[], T_Result],
        pa: typing.Callable[[], T_Result],
        pr: typing.Callable[[], T_Result],
        pw: typing.Callable[[], T_Result],
        ri: typing.Callable[[], T_Result],
        sc: typing.Callable[[], T_Result],
        sd: typing.Callable[[], T_Result],
        tn: typing.Callable[[], T_Result],
        tx: typing.Callable[[], T_Result],
        ut: typing.Callable[[], T_Result],
        vi: typing.Callable[[], T_Result],
        vt: typing.Callable[[], T_Result],
        va: typing.Callable[[], T_Result],
        wa: typing.Callable[[], T_Result],
        wv: typing.Callable[[], T_Result],
        wi: typing.Callable[[], T_Result],
        wy: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is State.AA:
            return aa()
        if self is State.AE:
            return ae()
        if self is State.AP:
            return ap()
        if self is State.AL:
            return al()
        if self is State.AK:
            return ak()
        if self is State.AS:
            return as_()
        if self is State.AZ:
            return az()
        if self is State.AR:
            return ar()
        if self is State.CA:
            return ca()
        if self is State.CO:
            return co()
        if self is State.CT:
            return ct()
        if self is State.DC:
            return dc()
        if self is State.DE:
            return de()
        if self is State.FL:
            return fl()
        if self is State.FM:
            return fm()
        if self is State.GA:
            return ga()
        if self is State.GU:
            return gu()
        if self is State.HI:
            return hi()
        if self is State.ID:
            return id()
        if self is State.IL:
            return il()
        if self is State.IN:
            return in_()
        if self is State.IA:
            return ia()
        if self is State.KS:
            return ks()
        if self is State.KY:
            return ky()
        if self is State.LA:
            return la()
        if self is State.ME:
            return me()
        if self is State.MD:
            return md()
        if self is State.MA:
            return ma()
        if self is State.MH:
            return mh()
        if self is State.MI:
            return mi()
        if self is State.MN:
            return mn()
        if self is State.MP:
            return mp()
        if self is State.MS:
            return ms()
        if self is State.MO:
            return mo()
        if self is State.MT:
            return mt()
        if self is State.NE:
            return ne()
        if self is State.NV:
            return nv()
        if self is State.NH:
            return nh()
        if self is State.NJ:
            return nj()
        if self is State.NM:
            return nm()
        if self is State.NY:
            return ny()
        if self is State.NC:
            return nc()
        if self is State.ND:
            return nd()
        if self is State.OH:
            return oh()
        if self is State.OK:
            return ok()
        if self is State.OR:
            return or_()
        if self is State.PA:
            return pa()
        if self is State.PR:
            return pr()
        if self is State.PW:
            return pw()
        if self is State.RI:
            return ri()
        if self is State.SC:
            return sc()
        if self is State.SD:
            return sd()
        if self is State.TN:
            return tn()
        if self is State.TX:
            return tx()
        if self is State.UT:
            return ut()
        if self is State.VI:
            return vi()
        if self is State.VT:
            return vt()
        if self is State.VA:
            return va()
        if self is State.WA:
            return wa()
        if self is State.WV:
            return wv()
        if self is State.WI:
            return wi()
        if self is State.WY:
            return wy()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class EligibilityStatus(str, enum.Enum):
    ACTIVE = "ACTIVE"
    INACTIVE = "INACTIVE"
    UNKNOWN = "UNKNOWN"

    def visit(
        self,
        active: typing.Callable[[], T_Result],
        inactive: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is EligibilityStatus.ACTIVE:
            return active()
        if self is EligibilityStatus.INACTIVE:
            return inactive()
        if self is EligibilityStatus.UNKNOWN:
            return unknown()



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts


class NonInsurancePayerCategoryUpdate_Remove(pydantic.BaseModel):
    type: typing.Literal["remove"] = "remove"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class NonInsurancePayerCategoryUpdate_Set(pydantic.BaseModel):
    value: str
    type: typing.Literal["set"] = "set"

    class Config:
        frozen = True
        smart_union = True


NonInsurancePayerCategoryUpdate = typing.Union[
    NonInsurancePayerCategoryUpdate_Remove, NonInsurancePayerCategoryUpdate_Set
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class UniversalServiceIdentifier(str, enum.Enum):
    MD_VISIT = "MD_Visit"
    TREATMENT = "Treatment"
    TESTS = "Tests"
    ACTIVITY = "Activity"

    def visit(
        self,
        md_visit: typing.Callable[[], T_Result],
        treatment: typing.Callable[[], T_Result],
        tests: typing.Callable[[], T_Result],
        activity: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is UniversalServiceIdentifier.MD_VISIT:
            return md_visit()
        if self is UniversalServiceIdentifier.TREATMENT:
            return treatment()
        if self is UniversalServiceIdentifier.TESTS:
            return tests()
        if self is UniversalServiceIdentifier.ACTIVITY:
            return activity()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ....core.datetime_utils import serialize_datetime
from ....core.pydantic_utilities import deep_union_pydantic_dicts
from .diagnosis_id import DiagnosisId
from .standalone_diagnosis_create import StandaloneDiagnosisCreate


class Diagnosis(StandaloneDiagnosisCreate):
    """
    Examples
    --------
    import datetime
    import uuid

    from candid import Diagnosis, DiagnosisTypeCode

    Diagnosis(
        diagnosis_id=uuid.UUID(
            "5c770e00-4bbf-42af-a73f-99c5e91fc0db",
        ),
        created_at=datetime.datetime.fromisoformat(
            "2023-01-01 00:00:00+00:00",
        ),
        updated_at=datetime.datetime.fromisoformat(
            "2023-01-01 00:00:00+00:00",
        ),
        encounter_id=uuid.UUID(
            "3f63985b-51a4-4dd4-9418-7d50b2520792",
        ),
        name="John Doe",
        code_type=DiagnosisTypeCode.ABF,
        code="I10",
    )
    """

    diagnosis_id: DiagnosisId
    created_at: dt.datetime
    updated_at: dt.datetime

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .types import (
    BillableStatusType,
    CashPayPayerErrorMessage,
    ClinicalNote,
    ClinicalNoteCategory,
    ClinicalNoteCategoryCreate,
    CodingAttributionType,
    Encounter,
    EncounterBase,
    EncounterExternalIdUniquenessErrorType,
    EncounterGuarantorMissingContactInfoErrorType,
    EncounterOwnerOfNextActionType,
    EncounterPage,
    EncounterPatientControlNumberUniquenessErrorType,
    EncounterSortOptions,
    EncounterSubmissionOriginType,
    IntakeFollowUp,
    IntakeFollowUpId,
    IntakeQuestion,
    IntakeQuestionId,
    IntakeResponseAndFollowUps,
    Intervention,
    InterventionCategory,
    KeyDoesNotExistError,
    Lab,
    LabCodeType,
    Medication,
    MultipleInstancesForSchemaError,
    NoteCategory,
    PatientHistoryCategory,
    PatientHistoryCategoryEnum,
    PriorAuthorizationNumber,
    ResponsiblePartyType,
    RxCui,
    SchemaDoesNotExistError,
    SchemaInstanceValidationError,
    SchemaInstanceValidationError_KeyDoesNotExist,
    SchemaInstanceValidationError_MultipleInstancesForSchema,
    SchemaInstanceValidationError_SchemaDoesNotExist,
    SchemaInstanceValidationError_SchemaUnauthorizedAccess,
    SchemaInstanceValidationError_ValueDoesNotMatchKeyType,
    SchemaInstanceValidationFailure,
    SchemaUnauthorizedAccessError,
    ServiceAuthorizationExceptionCode,
    SynchronicityType,
    ValueDoesNotMatchKeyTypeError,
    Vitals,
    VitalsUpdate,
)
from .errors import (
    CashPayPayerError,
    EncounterExternalIdUniquenessError,
    EncounterGuarantorMissingContactInfoError,
    EncounterPatientControlNumberUniquenessError,
    SchemaInstanceValidationHttpFailure,
)

__all__ = [
    "BillableStatusType",
    "CashPayPayerError",
    "CashPayPayerErrorMessage",
    "ClinicalNote",
    "ClinicalNoteCategory",
    "ClinicalNoteCategoryCreate",
    "CodingAttributionType",
    "Encounter",
    "EncounterBase",
    "EncounterExternalIdUniquenessError",
    "EncounterExternalIdUniquenessErrorType",
    "EncounterGuarantorMissingContactInfoError",
    "EncounterGuarantorMissingContactInfoErrorType",
    "EncounterOwnerOfNextActionType",
    "EncounterPage",
    "EncounterPatientControlNumberUniquenessError",
    "EncounterPatientControlNumberUniquenessErrorType",
    "EncounterSortOptions",
    "EncounterSubmissionOriginType",
    "IntakeFollowUp",
    "IntakeFollowUpId",
    "IntakeQuestion",
    "IntakeQuestionId",
    "IntakeResponseAndFollowUps",
    "Intervention",
    "InterventionCategory",
    "KeyDoesNotExistError",
    "Lab",
    "LabCodeType",
    "Medication",
    "MultipleInstancesForSchemaError",
    "NoteCategory",
    "PatientHistoryCategory",
    "PatientHistoryCategoryEnum",
    "PriorAuthorizationNumber",
    "ResponsiblePartyType",
    "RxCui",
    "SchemaDoesNotExistError",
    "SchemaInstanceValidationError",
    "SchemaInstanceValidationError_KeyDoesNotExist",
    "SchemaInstanceValidationError_MultipleInstancesForSchema",
    "SchemaInstanceValidationError_SchemaDoesNotExist",
    "SchemaInstanceValidationError_SchemaUnauthorizedAccess",
    "SchemaInstanceValidationError_ValueDoesNotMatchKeyType",
    "SchemaInstanceValidationFailure",
    "SchemaInstanceValidationHttpFailure",
    "SchemaUnauthorizedAccessError",
    "ServiceAuthorizationExceptionCode",
    "SynchronicityType",
    "ValueDoesNotMatchKeyTypeError",
    "Vitals",
    "VitalsUpdate",
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    NonInsurancePayerRefund,
    NonInsurancePayerRefundCreate,
    NonInsurancePayerRefundId,
    NonInsurancePayerRefundSortField,
    NonInsurancePayerRefundsPage,
)

__all__ = [
    "NonInsurancePayerRefund",
    "NonInsurancePayerRefundCreate",
    "NonInsurancePayerRefundId",
    "NonInsurancePayerRefundSortField",
    "NonInsurancePayerRefundsPage",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ....core.datetime_utils import serialize_datetime
from ....core.pydantic_utilities import deep_union_pydantic_dicts
from .page_token import PageToken


class ResourcePage(pydantic.BaseModel):
    """
    Examples
    --------
    from candid import ResourcePage

    ResourcePage(
        prev_page_token="eyJ0b2tlbiI6IjEiLCJwYWdlX3Rva2VuIjoiMiJ9",
        next_page_token="eyAiZm9vIjogImJhciJ9o8dj3FU83fFJe8dalz4A",
    )
    """

    prev_page_token: typing.Optional[PageToken] = None
    next_page_token: typing.Optional[PageToken] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic

from .....commons.types.npi import Npi
from .....commons.types.tax_id import TaxId


class PayeeIdentifier_Npi(pydantic.BaseModel):
    value: Npi
    type: typing.Literal["npi"] = "npi"

    class Config:
        frozen = True
        smart_union = True


class PayeeIdentifier_Tin(pydantic.BaseModel):
    value: TaxId
    type: typing.Literal["tin"] = "tin"

    class Config:
        frozen = True
        smart_union = True


class PayeeIdentifier_CmsPlanId(pydantic.BaseModel):
    value: str
    type: typing.Literal["cms_plan_id"] = "cms_plan_id"

    class Config:
        frozen = True
        smart_union = True


PayeeIdentifier = typing.Union[PayeeIdentifier_Npi, PayeeIdentifier_Tin, PayeeIdentifier_CmsPlanId]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class TaskActionType(str, enum.Enum):
    CLOSE_TASK = "close_task"
    CLOSE_TASK_AND_REPROCESS = "close_task_and_reprocess"

    def visit(
        self, close_task: typing.Callable[[], T_Result], close_task_and_reprocess: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is TaskActionType.CLOSE_TASK:
            return close_task()
        if self is TaskActionType.CLOSE_TASK_AND_REPROCESS:
            return close_task_and_reprocess()



# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .resources.v_3.client import AsyncV3Client, V3Client


class FeeSchedulesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.v_3 = V3Client(client_wrapper=self._client_wrapper)


class AsyncFeeSchedulesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.v_3 = AsyncV3Client(client_wrapper=self._client_wrapper)



# This file was auto-generated by Fern from our API Definition.

from .types import (
    Contact,
    ExternalProvenance,
    FilingOrder,
    Guarantor,
    MaritalStatus,
    MutablePatient,
    Patient,
    PatientPage,
    PatientSortField,
    PotentialDuplicatePatient,
    PotentialDuplicatePatientsErrorBody,
)
from .errors import PotentialDuplicatePatients

__all__ = [
    "Contact",
    "ExternalProvenance",
    "FilingOrder",
    "Guarantor",
    "MaritalStatus",
    "MutablePatient",
    "Patient",
    "PatientPage",
    "PatientSortField",
    "PotentialDuplicatePatient",
    "PotentialDuplicatePatients",
    "PotentialDuplicatePatientsErrorBody",
]
